% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/modelmetrics.R
\docType{methods}
\name{modelmetrics}
\alias{modelmetrics}
\alias{modelmetrics,factor,factor-method}
\alias{modelmetrics,factor,matrix-method}
\alias{modelmetrics,factor,numeric-method}
\alias{modelmetrics,matrix,matrix-method}
\alias{modelmetrics,numeric,matrix-method}
\alias{modelmetrics,numeric,numeric-method}
\alias{modelmetrics,Surv,matrix-method}
\alias{modelmetrics,Surv,numeric-method}
\title{Model Performance Metrices}
\usage{
modelmetrics(observed, predicted, na.rm = FALSE, ...)

\S4method{modelmetrics}{factor,factor}(observed, predicted,
  na.rm = FALSE, ...)

\S4method{modelmetrics}{factor,matrix}(observed, predicted,
  na.rm = FALSE, ...)

\S4method{modelmetrics}{factor,numeric}(observed, predicted,
  cutoff = 0.5, cutoff_index = function(sens, spec) sens + spec,
  na.rm = FALSE, ...)

\S4method{modelmetrics}{matrix,matrix}(observed, predicted,
  na.rm = FALSE, ...)

\S4method{modelmetrics}{numeric,matrix}(observed, predicted,
  na.rm = FALSE, ...)

\S4method{modelmetrics}{numeric,numeric}(observed, predicted,
  na.rm = FALSE, ...)

\S4method{modelmetrics}{Surv,matrix}(observed, predicted, times,
  na.rm = FALSE, ...)

\S4method{modelmetrics}{Surv,numeric}(observed, predicted, na.rm = FALSE,
  ...)
}
\arguments{
\item{observed}{vector of observed responses.}

\item{predicted}{model-predicted responses.}

\item{na.rm}{logical indicating whether to remove \code{NA} values.}

\item{...}{arguments passed to or from other methods.}

\item{cutoff}{threshold above which probabilities are classified as success.}

\item{cutoff_index}{function to calculate a desired sensitivity-specificity
tradeoff.}

\item{times}{numeric vector of follow-up times at which survival events
were predicted.}
}
\description{
Compute measures of model performance.
}
\examples{
## Survival response example
library(survival)

fo <- Surv(time, status) ~ age + sex + ph.ecog + ph.karno + pat.karno +
                           meal.cal + wt.loss
gbmfit <- fit(fo, lung, GBMModel)

obs <- response(fo, lung)
pred <- predict(gbmfit, newdata = lung, type = "prob")
modelmetrics(obs, pred)

}
\seealso{
\code{\link{predict}}, \code{\linkS4class{MLControl}}
}
